@@ -1,5 +1,6 @@
 from pypop7.optimizers.eda.eda import EDA
 from pypop7.optimizers.eda.umda import UMDA
+from pypop7.optimizers.eda.emna import EMNA
 
 
-__all__ = [EDA, UMDA]
+__all__ = [EDA, UMDA, EMNA]
