@@ -7,9 +7,11 @@ from pypop7.optimizers.es.saes import SAES
 from pypop7.optimizers.es.maes import MAES
 from pypop7.optimizers.es.fmaes import FMAES
 from pypop7.optimizers.es.r1es import R1ES
+from pypop7.optimizers.es.lmcmaes import LMCMAES
+from pypop7.optimizers.es.lmcma import LMCMA
 
 
 __all__ = [ES,
            RES, SSAES, DSAES, CSAES, SAES,  # representative ES versions during development
            MAES, FMAES,  # modern ES versions often with state-of-the-art performance
-           R1ES]  # especially for large-scale black-box optimization
+           R1ES, LMCMAES, LMCMA]  # especially for large-scale black-box optimization
